Module error_model

Module error_model 

Sequencing error models for realistic quality score and error simulation.

The ErrorModel trait defines the interface for position-dependent error models. The apply_errors free function applies any error model to a read’s bases, introducing substitution errors and generating quality scores.

Modules

illumina

Enums

ReadEnd
Which read in a pair this is.

Traits

ErrorModel
Trait for position-dependent sequencing error models.

Functions

apply_errors
Apply sequencing errors to a read’s bases in place using the given error model, returning the number of errors and quality scores (Phred+33).